@@ -63,54 +63,61 @@ class JobsV1Beta3RestInterceptor:
 
     .. code-block:: python
         class MyCustomJobsV1Beta3Interceptor(JobsV1Beta3RestInterceptor):
-            def pre_aggregated_list_jobs(request, metadata):
+            def pre_aggregated_list_jobs(self, request, metadata):
                 logging.log(f"Received request: {request}")
                 return request, metadata
 
-            def post_aggregated_list_jobs(response):
+            def post_aggregated_list_jobs(self, response):
                 logging.log(f"Received response: {response}")
+                return response
 
-            def pre_check_active_jobs(request, metadata):
+            def pre_check_active_jobs(self, request, metadata):
                 logging.log(f"Received request: {request}")
                 return request, metadata
 
-            def post_check_active_jobs(response):
+            def post_check_active_jobs(self, response):
                 logging.log(f"Received response: {response}")
+                return response
 
-            def pre_create_job(request, metadata):
+            def pre_create_job(self, request, metadata):
                 logging.log(f"Received request: {request}")
                 return request, metadata
 
-            def post_create_job(response):
+            def post_create_job(self, response):
                 logging.log(f"Received response: {response}")
+                return response
 
-            def pre_get_job(request, metadata):
+            def pre_get_job(self, request, metadata):
                 logging.log(f"Received request: {request}")
                 return request, metadata
 
-            def post_get_job(response):
+            def post_get_job(self, response):
                 logging.log(f"Received response: {response}")
+                return response
 
-            def pre_list_jobs(request, metadata):
+            def pre_list_jobs(self, request, metadata):
                 logging.log(f"Received request: {request}")
                 return request, metadata
 
-            def post_list_jobs(response):
+            def post_list_jobs(self, response):
                 logging.log(f"Received response: {response}")
+                return response
 
-            def pre_snapshot_job(request, metadata):
+            def pre_snapshot_job(self, request, metadata):
                 logging.log(f"Received request: {request}")
                 return request, metadata
 
-            def post_snapshot_job(response):
+            def post_snapshot_job(self, response):
                 logging.log(f"Received response: {response}")
+                return response
 
-            def pre_update_job(request, metadata):
+            def pre_update_job(self, request, metadata):
                 logging.log(f"Received request: {request}")
                 return request, metadata
 
-            def post_update_job(response):
+            def post_update_job(self, response):
                 logging.log(f"Received response: {response}")
+                return response
 
         transport = JobsV1Beta3RestTransport(interceptor=MyCustomJobsV1Beta3Interceptor())
         client = JobsV1Beta3Client(transport=transport)
@@ -255,19 +262,16 @@ class JobsV1Beta3RestTransport(JobsV1Beta3Transport):
 
     It sends JSON representations of protocol buffers over HTTP/1.1
 
-    NOTE: This REST transport functionality is currently in a beta
-    state (preview). We welcome your feedback via an issue in this
-    library's source repository. Thank you!
     """
 
     def __init__(
         self,
         *,
         host: str = "dataflow.googleapis.com",
-        credentials: ga_credentials.Credentials = None,
-        credentials_file: str = None,
-        scopes: Sequence[str] = None,
-        client_cert_source_for_mtls: Callable[[], Tuple[bytes, bytes]] = None,
+        credentials: Optional[ga_credentials.Credentials] = None,
+        credentials_file: Optional[str] = None,
+        scopes: Optional[Sequence[str]] = None,
+        client_cert_source_for_mtls: Optional[Callable[[], Tuple[bytes, bytes]]] = None,
         quota_project_id: Optional[str] = None,
         client_info: gapic_v1.client_info.ClientInfo = DEFAULT_CLIENT_INFO,
         always_use_jwt_access: Optional[bool] = False,
@@ -277,39 +281,35 @@ class JobsV1Beta3RestTransport(JobsV1Beta3Transport):
     ) -> None:
         """Instantiate the transport.
 
-        NOTE: This REST transport functionality is currently in a beta
-        state (preview). We welcome your feedback via a GitHub issue in
-        this library's repository. Thank you!
+        Args:
+            host (Optional[str]):
+                 The hostname to connect to.
+            credentials (Optional[google.auth.credentials.Credentials]): The
+                authorization credentials to attach to requests. These
+                credentials identify the application to the service; if none
+                are specified, the client will attempt to ascertain the
+                credentials from the environment.
 
-         Args:
-             host (Optional[str]):
-                  The hostname to connect to.
-             credentials (Optional[google.auth.credentials.Credentials]): The
-                 authorization credentials to attach to requests. These
-                 credentials identify the application to the service; if none
-                 are specified, the client will attempt to ascertain the
-                 credentials from the environment.
-
-             credentials_file (Optional[str]): A file with credentials that can
-                 be loaded with :func:`google.auth.load_credentials_from_file`.
-                 This argument is ignored if ``channel`` is provided.
-             scopes (Optional(Sequence[str])): A list of scopes. This argument is
-                 ignored if ``channel`` is provided.
-             client_cert_source_for_mtls (Callable[[], Tuple[bytes, bytes]]): Client
-                 certificate to configure mutual TLS HTTP channel. It is ignored
-                 if ``channel`` is provided.
-             quota_project_id (Optional[str]): An optional project to use for billing
-                 and quota.
-             client_info (google.api_core.gapic_v1.client_info.ClientInfo):
-                 The client info used to send a user-agent string along with
-                 API requests. If ``None``, then default info will be used.
-                 Generally, you only need to set this if you are developing
-                 your own client library.
-             always_use_jwt_access (Optional[bool]): Whether self signed JWT should
-                 be used for service account credentials.
-             url_scheme: the protocol scheme for the API endpoint.  Normally
-                 "https", but for testing or local servers,
-                 "http" can be specified.
+            credentials_file (Optional[str]): A file with credentials that can
+                be loaded with :func:`google.auth.load_credentials_from_file`.
+                This argument is ignored if ``channel`` is provided.
+            scopes (Optional(Sequence[str])): A list of scopes. This argument is
+                ignored if ``channel`` is provided.
+            client_cert_source_for_mtls (Callable[[], Tuple[bytes, bytes]]): Client
+                certificate to configure mutual TLS HTTP channel. It is ignored
+                if ``channel`` is provided.
+            quota_project_id (Optional[str]): An optional project to use for billing
+                and quota.
+            client_info (google.api_core.gapic_v1.client_info.ClientInfo):
+                The client info used to send a user-agent string along with
+                API requests. If ``None``, then default info will be used.
+                Generally, you only need to set this if you are developing
+                your own client library.
+            always_use_jwt_access (Optional[bool]): Whether self signed JWT should
+                be used for service account credentials.
+            url_scheme: the protocol scheme for the API endpoint.  Normally
+                "https", but for testing or local servers,
+                "http" can be specified.
         """
         # Run the base constructor
         # TODO(yon-mg): resolve other ctor params i.e. scopes, quota, etc.
@@ -349,7 +349,7 @@ class JobsV1Beta3RestTransport(JobsV1Beta3Transport):
             request: jobs.ListJobsRequest,
             *,
             retry: OptionalRetry = gapic_v1.method.DEFAULT,
-            timeout: float = None,
+            timeout: Optional[float] = None,
             metadata: Sequence[Tuple[str, str]] = (),
         ) -> jobs.ListJobsResponse:
             r"""Call the aggregated list jobs method over HTTP.
@@ -396,10 +396,12 @@ class JobsV1Beta3RestTransport(JobsV1Beta3Transport):
                 json_format.MessageToJson(
                     transcoded_request["query_params"],
                     including_default_value_fields=False,
-                    use_integers_for_enums=False,
+                    use_integers_for_enums=True,
                 )
             )
 
+            query_params["$alt"] = "json;enum-encoding=int"
+
             # Send the request
             headers = dict(metadata)
             headers["Content-Type"] = "application/json"
@@ -432,7 +434,7 @@ class JobsV1Beta3RestTransport(JobsV1Beta3Transport):
             request: jobs.CheckActiveJobsRequest,
             *,
             retry: OptionalRetry = gapic_v1.method.DEFAULT,
-            timeout: float = None,
+            timeout: Optional[float] = None,
             metadata: Sequence[Tuple[str, str]] = (),
         ) -> jobs.CheckActiveJobsResponse:
             raise RuntimeError(
@@ -448,7 +450,7 @@ class JobsV1Beta3RestTransport(JobsV1Beta3Transport):
             request: jobs.CreateJobRequest,
             *,
             retry: OptionalRetry = gapic_v1.method.DEFAULT,
-            timeout: float = None,
+            timeout: Optional[float] = None,
             metadata: Sequence[Tuple[str, str]] = (),
         ) -> jobs.Job:
             r"""Call the create job method over HTTP.
@@ -492,7 +494,7 @@ class JobsV1Beta3RestTransport(JobsV1Beta3Transport):
             body = json_format.MessageToJson(
                 transcoded_request["body"],
                 including_default_value_fields=False,
-                use_integers_for_enums=False,
+                use_integers_for_enums=True,
             )
             uri = transcoded_request["uri"]
             method = transcoded_request["method"]
@@ -502,10 +504,12 @@ class JobsV1Beta3RestTransport(JobsV1Beta3Transport):
                 json_format.MessageToJson(
                     transcoded_request["query_params"],
                     including_default_value_fields=False,
-                    use_integers_for_enums=False,
+                    use_integers_for_enums=True,
                 )
             )
 
+            query_params["$alt"] = "json;enum-encoding=int"
+
             # Send the request
             headers = dict(metadata)
             headers["Content-Type"] = "application/json"
@@ -539,7 +543,7 @@ class JobsV1Beta3RestTransport(JobsV1Beta3Transport):
             request: jobs.GetJobRequest,
             *,
             retry: OptionalRetry = gapic_v1.method.DEFAULT,
-            timeout: float = None,
+            timeout: Optional[float] = None,
             metadata: Sequence[Tuple[str, str]] = (),
         ) -> jobs.Job:
             r"""Call the get job method over HTTP.
@@ -584,10 +588,12 @@ class JobsV1Beta3RestTransport(JobsV1Beta3Transport):
                 json_format.MessageToJson(
                     transcoded_request["query_params"],
                     including_default_value_fields=False,
-                    use_integers_for_enums=False,
+                    use_integers_for_enums=True,
                 )
             )
 
+            query_params["$alt"] = "json;enum-encoding=int"
+
             # Send the request
             headers = dict(metadata)
             headers["Content-Type"] = "application/json"
@@ -620,7 +626,7 @@ class JobsV1Beta3RestTransport(JobsV1Beta3Transport):
             request: jobs.ListJobsRequest,
             *,
             retry: OptionalRetry = gapic_v1.method.DEFAULT,
-            timeout: float = None,
+            timeout: Optional[float] = None,
             metadata: Sequence[Tuple[str, str]] = (),
         ) -> jobs.ListJobsResponse:
             r"""Call the list jobs method over HTTP.
@@ -669,10 +675,12 @@ class JobsV1Beta3RestTransport(JobsV1Beta3Transport):
                 json_format.MessageToJson(
                     transcoded_request["query_params"],
                     including_default_value_fields=False,
-                    use_integers_for_enums=False,
+                    use_integers_for_enums=True,
                 )
             )
 
+            query_params["$alt"] = "json;enum-encoding=int"
+
             # Send the request
             headers = dict(metadata)
             headers["Content-Type"] = "application/json"
@@ -705,7 +713,7 @@ class JobsV1Beta3RestTransport(JobsV1Beta3Transport):
             request: jobs.SnapshotJobRequest,
             *,
             retry: OptionalRetry = gapic_v1.method.DEFAULT,
-            timeout: float = None,
+            timeout: Optional[float] = None,
             metadata: Sequence[Tuple[str, str]] = (),
         ) -> snapshots.Snapshot:
             r"""Call the snapshot job method over HTTP.
@@ -747,7 +755,7 @@ class JobsV1Beta3RestTransport(JobsV1Beta3Transport):
             body = json_format.MessageToJson(
                 transcoded_request["body"],
                 including_default_value_fields=False,
-                use_integers_for_enums=False,
+                use_integers_for_enums=True,
             )
             uri = transcoded_request["uri"]
             method = transcoded_request["method"]
@@ -757,10 +765,12 @@ class JobsV1Beta3RestTransport(JobsV1Beta3Transport):
                 json_format.MessageToJson(
                     transcoded_request["query_params"],
                     including_default_value_fields=False,
-                    use_integers_for_enums=False,
+                    use_integers_for_enums=True,
                 )
             )
 
+            query_params["$alt"] = "json;enum-encoding=int"
+
             # Send the request
             headers = dict(metadata)
             headers["Content-Type"] = "application/json"
@@ -794,7 +804,7 @@ class JobsV1Beta3RestTransport(JobsV1Beta3Transport):
             request: jobs.UpdateJobRequest,
             *,
             retry: OptionalRetry = gapic_v1.method.DEFAULT,
-            timeout: float = None,
+            timeout: Optional[float] = None,
             metadata: Sequence[Tuple[str, str]] = (),
         ) -> jobs.Job:
             r"""Call the update job method over HTTP.
@@ -838,7 +848,7 @@ class JobsV1Beta3RestTransport(JobsV1Beta3Transport):
             body = json_format.MessageToJson(
                 transcoded_request["body"],
                 including_default_value_fields=False,
-                use_integers_for_enums=False,
+                use_integers_for_enums=True,
             )
             uri = transcoded_request["uri"]
             method = transcoded_request["method"]
@@ -848,10 +858,12 @@ class JobsV1Beta3RestTransport(JobsV1Beta3Transport):
                 json_format.MessageToJson(
                     transcoded_request["query_params"],
                     including_default_value_fields=False,
-                    use_integers_for_enums=False,
+                    use_integers_for_enums=True,
                 )
             )
 
+            query_params["$alt"] = "json;enum-encoding=int"
+
             # Send the request
             headers = dict(metadata)
             headers["Content-Type"] = "application/json"
